=============================
Joints Framework (Docstrings)
=============================

Joint (Docstrings)
==================

.. module:: sympy.physics.mechanics.joint

.. autoclass:: Joint
   :members:

.. autoclass:: PinJoint
   :members:

.. autoclass:: PrismaticJoint
   :members:

.. autoclass:: CylindricalJoint
   :members:

.. autoclass:: PlanarJoint
   :members:

.. autoclass:: SphericalJoint
   :members:

.. autoclass:: WeldJoint
   :members:

.. automodule:: sympy.physics.mechanics.jointsmethod
   :members:
